@@ -10,7 +10,7 @@ use Carp;
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.12';
+our $VERSION   = '0.13';
 
 our (%cached);
 
@@ -117,6 +117,10 @@ sub holidays {
             {    # VIC labour day
                 $holidays{$holiday} = 'Labour Day';
             }
+            foreach my $holiday ( _compute_vic_grand_final_eve_day($year) )
+            {    # VIC grand final day
+                $holidays{$holiday} = 'Grand Final Eve';
+            }
         }
         elsif ( $state eq 'WA' ) {
             foreach my $holiday ( _compute_wa_labour_day($year) )
@@ -930,6 +934,24 @@ sub _compute_vic_labour_day {    # second monday in march
     return ( sprintf( "%02d%02d", ( $month + 1 ), $day ) );
 }
 
+sub _compute_vic_grand_final_eve_day {    # i have no words ...
+    my ($year) = @_;
+    my ( $day, $month );
+    if ( $year == 2015 ) {
+        $day   = 2;
+        $month = 9;
+    }
+    elsif ( $year < 2015 ) {
+        return ();
+    }
+    else {
+        croak(
+"Don't know how to calculate Grand Final Eve Day in VIC for this year\n"
+        );
+    }
+    return ( sprintf( "%02d%02d", ( $month + 1 ), $day ) );
+}
+
 sub _compute_wa_labour_day {    # first monday in march
     my ($year)    = @_;
     my ($day)     = 1;
